@@ -6,6 +6,8 @@ Created on Tue Dec 21 11:09:09 2021
 """
 
 # loading all the packages
+import warnings
+warnings.filterwarnings("ignore", category=DeprecationWarning) 
 import os
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 import pandas as pd
@@ -176,7 +178,7 @@ def run(text_input, show_plot=False):
                 fig.update_traces(width=0.5)
                 fig.add_trace(go.Line(x=x, y=bias))
                 fig.update_layout(title_text='Bias probability for new recomemendations', showlegend=False)
-		fig.update_layout(
+                fig.update_layout(
                     autosize=False,
                     width=800,
                     height=600)
